from .calculations import calculate_mean
from .equations import solve_quadratic, nth_term
from .models import Student, Experiment

__version__ = '0.1.3'

'''
This is a package called ensfc-stemm. It contains two modules: calculations and equations.
'''